
# Generated by CodiumAI
import argparse
from runit.cli import create_new_project
from runit.constants import CURRENT_PROJECT
from runit.exceptions import ProjectNameNotSpecified
from runit.exceptions import ProjectExistsError


import pytest

class TestCreateNewProject:

    # Create a new project with a specified name and language.
    def test_create_new_project_with_specified_name_and_language(self):
        args = argparse.Namespace(name="my_project", language="python", runtime=None, private=False)
        create_new_project(args)
        assert CURRENT_PROJECT == "my_project"

    # Successfully create a new project with default language.
    def test_create_new_project_with_default_language(self):
        args = argparse.Namespace(name="my_project", language=None, runtime=None, private=False)
        create_new_project(args)
        assert CURRENT_PROJECT == "my_project"

    # Create a new project with a specified runtime.
    def test_create_new_project_with_specified_runtime(self):
        args = argparse.Namespace(name="my_project", language="python", runtime="python3.9", private=False)
        create_new_project(args)
        assert CURRENT_PROJECT == "my_project"

    # Raise an exception if project name is not specified.
    def test_raise_exception_if_project_name_not_specified(self):
        args = argparse.Namespace(name=None, language="python", runtime=None, private=False)
        with pytest.raises(ProjectNameNotSpecified):
            create_new_project(args)

    # Raise an exception if project with specified name already exists.
    def test_raise_exception_if_project_with_specified_name_already_exists(self):
        args = argparse.Namespace(name="existing_project", language="python", runtime=None, private=False)
        with pytest.raises(ProjectExistsError):
            create_new_project(args)

    # Raise an exception if project creation fails.
    def test_raise_exception_if_project_creation_fails(self):
        args = argparse.Namespace(name="failed_project", language="python", runtime=None, private=False)
        with pytest.raises(Exception):
            create_new_project(args)